pl\_extension.callbacks.linear\_scaling\_rule.LinearScalingRule
===============================================================

.. currentmodule:: pl_extension.callbacks.linear_scaling_rule

.. autoclass:: LinearScalingRule